/*!
 * @file advcal_dlg.h
 * @brief This is the header file for the AdvCalDlg class.
 *
 * Copyright 2014 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef ADVCAL_DLG_H
#define ADVCAL_DLG_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <QDialog>
#include <stdint.h>

namespace Ui
{
class AdvCalDlg;
}

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------
class CameraMDI;

class AdvCalDlg : public QDialog
{
    Q_OBJECT

public:
    explicit AdvCalDlg(QWidget *parent = nullptr);
    ~AdvCalDlg();

    bool    do_auto_offset(void);

public slots:
    virtual void    done(int result);
    virtual int     exec();

private slots:
    void    auto_offset_change(void);
    void    handle_gain_change(int new_value);
    void    handle_offset_change(int new_value);
    void    read_complete(uint32_t ip_addr, uint32_t reg_addr);
    void    restore_settings(void);

private:
    void    update_sensor_dac(uint32_t dac_value);
    void    update_sensor_gain(uint32_t gain_value);

private:
    Ui::AdvCalDlg *ui;
    CameraMDI   *camera_ptr;                //!< Pointer to our camera object.
    int         num_gain_settings;          //!< Number of gain settings the sensor supports.
    const int   *gain_settings_array;       //!< Pointer to the gain settings value array in use.
    bool        offset_allowed;             //!< True of the sensor supports a DAC offset.

    uint32_t    orig_sensor_dac;            //!< The original sensor DAC/offset value, in case of a cancel.
    uint32_t    orig_sensor_gain;           //!< The original sensor gain value, in case of a cancel.
    bool        need_to_hide_histo;         //!< Flag to indicate if we need to hide the histogram when we're done.
};

#endif // ADVCAL_DLG_H
