/*!
 * @file camera_actions.h
 * @brief This is the header file for the CameraActions class.
 *
 * Group the Arm, Trigger, Live Mode, Review Mode controls in one,
 * easy to use, widget.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef CAMERA_ACTIONS_H
#define CAMERA_ACTIONS_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <stdint.h>
#include <QFrame>

namespace Ui
{
class CameraActions;
}

//--------------------------------------------------------------------
// Class Definition
//--------------------------------------------------------------------
class CameraActions : public QFrame
{
    Q_OBJECT

public:
    explicit CameraActions(QWidget *parent = nullptr);
    ~CameraActions();

    void    disable_actions();
    void    enable_actions();
    void    enable_multicam_mode();
    void    finish_update();
    void    reflect_camera_state(uint32_t camera_state, uint32_t part_state, uint32_t ltr_mode);
    void    set_arm_action(QAction *action_ptr);
    void    set_autosave_checked(bool checked);
    void    set_autosave_enabled(bool enabled);
    void    set_autosave_action(QAction *action_ptr);
    void    set_live_action(QAction *action_ptr);
    void    set_review_action(QAction *action_ptr);
    void    set_trigger_action(QAction *action_ptr);
    void    start_update();

private slots:
    void    delayed_init();

private:
    Ui::CameraActions   *ui;

    static const QString ARM_ACTION_NAME;
    static const QString AUTOSAVE_ENABLE_ACTION_NAME;
    static const QString TRIGGER_ACTION_NAME;
    static const QString LIVE_ACTION_NAME;
    static const QString REVIEW_ACTION_NAME;

    bool    multicam_mode;              //!< Flag to indicate if we're in multicamera mode.

    QAction *action_arm;
    QAction *action_autosave_enable;
    QAction *action_live;
    QAction *action_review;
    QAction *action_trigger;

    bool    enable_arm;                 //!< Flag to indicate if the ARM button should be enabled in multicamera mode.
    bool    enable_autosave;            //!< Flag to indicate if the Autosave button should be enabled in multicamera mode.
    bool    enable_live;                //!< Flag to indicate if the Live button should be enabled in multicamera mode.
    bool    enable_review;              //!< Flag to indicate if the Review button should be enabled in multicamera mode.
    bool    enable_trigger;             //!< Flag to indicate if the Trigger button should be enabled in multicamera mode.

    bool    use_dearm_icon;             //!< Flag to indicate if we're in de-arm mode (multicamera).
    bool    use_detrig_icon;            //!< Flag to indicate if we're in de-trigger mode (multicamera).
};

#endif // CAMERA_ACTIONS_H
