/*!
 * @file camera_log_search_dlg.cpp
 * @brief This is the source file for the Fastec Camera Log Search Dialog.
 *
 * This class is modelled after the Notepad "Find" dialog to provide
 * primative search functionality for the Camera Log Docking window.
 *
 * Copyright 2021 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef CAMERA_LOG_SEARCH_DLG_H
#define CAMERA_LOG_SEARCH_DLG_H

#include <QDialog>
#include <QTextDocument>

namespace Ui
{
class CameraLogSearchDialog;
}

namespace CAMLOG_SEARCH
{
//--------------------------------------------------------------------
// Constant, Macro and Type Definitions
//--------------------------------------------------------------------
//! Define the search directions for the start of a search dialog.
typedef enum
{
    SEARCH_DOWN = 0,        //!< Search from cursor anchor position to end.
    SEARCH_UP               //!< Search from cursor anchor position to beginning.
} SEARCH_DIRECTION;

}   // End of namespace CAMLOG_SEARCH.

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

//--------------------------------------------------------------------
// Class CameraLogSearchDialog
//--------------------------------------------------------------------

class CameraLogSearchDialog : public QDialog
{
    Q_OBJECT

protected:
    explicit CameraLogSearchDialog(QWidget *parent = nullptr, Qt::WindowFlags flags = Qt::WindowFlags());

public:
    ~CameraLogSearchDialog();

    static std::unique_ptr<CameraLogSearchDialog> CreateDialog(const QString& dialogTitleStr,
                                                               QWidget *parent = nullptr,
                                                               Qt::WindowFlags flags = Qt::WindowFlags());
    const QString&  getSearchString();

    CAMLOG_SEARCH::SEARCH_DIRECTION getSearchDirection();
    void    getSearchFlags(QTextDocument::FindFlags& findFlagsToSet);
    bool    getSearchMatchCase();
    bool    getSearchWholeWord();
    bool    getSearchWrapAround();

    void    setSearchDirection(CAMLOG_SEARCH::SEARCH_DIRECTION direction);
    void    setInfoMessage(const QString& messageToSet);
    void    setSearchMatchCase(bool useMatchCase);
    void    setSearchWholeWord(bool wholeWordsOnly);
    void    setSearchWrapAround(bool useWrapAround);
    bool    wasCanceled()                   { return got_cancel_sig; }

public slots:
    virtual void    cancelDialog();
    virtual void    findNext();

signals:
    void    searchForNext();

private:
    Ui::CameraLogSearchDialog *ui;

    bool    got_cancel_sig;             //!< True if we got a cancel signal.
    QString searchString;               //!< Takes on the value in the dialog for the search string when search initiated.

};

#endif // CAMERA_LOG_SEARCH_DLG_H
