#ifndef CAMERA_TELEMETRY_H
#define CAMERA_TELEMETRY_H

#include <QDockWidget>
#include <QStandardItem>
#include <QStandardItemModel>

namespace Ui
{
class CameraTelemetry;
}

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------
class QByteArray;
class QMdiSubWindow;

class CameraMDI;

class CameraTelemetry : public QDockWidget
{
    Q_OBJECT

public:
    explicit CameraTelemetry(QWidget *parent = nullptr);
    ~CameraTelemetry();

    CameraMDI *get_camera()             {return active_camera;}

signals:
    void parse_done(const QList<QStandardItem *>& new_row);

protected:
    void changeEvent(QEvent *e);
    void closeEvent(QCloseEvent *event);

private slots:
    void add_null_row();
    void changeTempScale();
    void exportLog();
    void logStartStop();
    void new_active_camera(QMdiSubWindow *window);
    void parse_complete(const QList<QStandardItem *>& new_row);
    void read_complete(uint32_t ip_addr, uint32_t reg_addr);
    void timerEvent(QTimerEvent *event);
    void updateValue(double dValue);
    void write_complete(uint32_t ip_addr, uint32_t reg_addr);

private:
    Ui::CameraTelemetry *ui;

    CameraMDI *active_camera;           //!< Pointer to the active camera.
    bool degCelsius;
    int logger;
    int poll_period;
    QStandardItemModel *log_data;
    QByteArray *json_data;

    double c_to_f(double c_value);
    double f_to_c(double f_value);
    static void parse_sensor_data(CameraTelemetry *tel_ptr, QByteArray *json_data);
};

#endif // CAMERA_TELEMETRY_H
