/*!
 * @file client_math.h
 * @brief This is the header file for the ClientMath class.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef CLIENT_MATH_H
#define CLIENT_MATH_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <stdint.h>

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

class QString;
class QTime;
class fiSensor;

namespace CLIENT_MATH
{
//--------------------------------------------------------------------
// Constant, Macro and Type Definitions
//--------------------------------------------------------------------

//! Define our increment in terms of QUADWORDs. The value is
//! calculated as 256 MBytes in quadwords because we are representing
//! a session length "quantum" as 1/4 of 1 GByte = 256 MBytes.
const uint32_t SESSION_INCR_QWORDS          = ((256 / 16) * 1024 * 1024);

}   // End of namespace CLIENT_MATH.

//--------------------------------------------------------------------
// Class declaration: ClientMath
//--------------------------------------------------------------------
class ClientMath
{
public:
    ClientMath();

#if 0
    static uint16_t calc_max_width(uint16_t height, uint32_t framerate);
    static uint16_t calc_max_height(uint16_t startx, uint16_t starty, uint16_t width, uint16_t height, uint32_t framerate);
#endif

    static uint32_t calc_frame_count(uint64_t part_size, uint32_t width, uint32_t height, uint32_t bit_mode, bool ltr, bool series3);
    static uint32_t calc_frame_size(uint32_t width, uint32_t height, uint32_t bit_depth);
    static uint32_t calc_ltr_frame_size(uint32_t width, uint32_t height, uint32_t bit_depth, bool series3);
    static uint64_t calc_ltr_part_size(uint64_t sector_count);
    static uint32_t calc_max_exposure(uint32_t cur_framerate, uint32_t frame_overhead);
    static uint32_t calc_max_framerate(fiSensor *p_sensor, uint32_t startx, uint32_t width, uint32_t height, int bit_depth, bool ltr, uint32_t ssd_bandwidth, bool series3);
    static uint32_t calc_max_session_count(uint32_t ddr2_size);
    static uint64_t calc_max_session_count64(uint64_t device_space);

    static uint32_t calc_max_total_frames(uint32_t ip_addr, uint32_t width, uint32_t height, bool ltr_enabled, bool series3);
    static uint64_t calc_record_ms(uint32_t frame_count, uint32_t frame_rate, QTime *duration = nullptr);
    static uint32_t calc_session_space(uint32_t session, uint32_t max_session, uint32_t ddr2_size, uint32_t ddr2_reserved);

    static uint32_t get_pfmd_size(bool series3);

    static uint64_t qword_to_bytes(uint64_t qw_value);
    static uint64_t bytes_to_qwords_rounded(uint64_t byte_value, bool round_up);
    static uint64_t sector_to_bytes(uint64_t sector_value);

    static QString fi_time_to_local(const QString& fi_time);
    static void    sbs_to_tm(uint32_t sbs, struct tm *tm_ptr);

    static uint32_t frame_rate_to_reg(float frame_rate);
    static float    reg_to_frame_rate(uint32_t reg_value);
};

#endif // CLIENT_MATH_H
