/*!
 * @file dcraw_util.h
 * @brief Wrappers for dcraw functionality.
 *
 * Copyright 2008-2017 LibRaw LLC (info@libraw.org)
 * Created: Sat Mar  8, 2008
 *
 * dcraw.c -- Dave Coffin's raw photo decoder
 * Copyright 1997-2014 by Dave Coffin, dcoffin a cybercom o net
 *
 * Copyright 2021 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef DCRAW_UTIL_H__
#define DCRAW_UTIL_H__

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <QImage>
#include <memory>

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------
class fiLibRaw;

//--------------------------------------------------------------------
// Class Declaration
//--------------------------------------------------------------------

class DcrawUtil
{
public:
    DcrawUtil();
    virtual ~DcrawUtil();

    // Convert the bytes into a QImage.
    QImage *raw_file(const QString& file_name);
    QImage *raw_process(uint8_t *dng_ptr, int dng_length);
    QImage *debayer(uint8_t *dng_ptr, int dng_length);

    void setGamma(double gamma_value)   { gamma = gamma_value; }

private:
    static void cleanupByteArray(void *info);
    static void cleanupImageMemory(void *info);

    std::unique_ptr<fiLibRaw> rawProcessor;     //!< Our LibRaw object.
    double gamma;                               //!< The gamma value we'll be using. Defaults to 2.2 (sRGB).
};


#endif /* !DCRAW_UTIL_H__ */
