/*!
 * @file export_dlg.h
 * @brief This is the header file for the ExportDlg class.
 *
 * Copyright 2014 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef EXPORT_DLG_H
#define EXPORT_DLG_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <QDialog>
#include <stdint.h>

namespace Ui
{
class ExportDlg;
}

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

class QProcess;

class ExportDlg : public QDialog
{
    Q_OBJECT

public:
    explicit ExportDlg(QWidget *parent = 0);
    ~ExportDlg();

    void    set_clip_range(uint32_t start_clip, uint32_t end_clip);
    void    set_fps(uint32_t fps)                         { record_fps = fps; }
    void    set_num_frames(uint32_t frame_count)          { num_frames = frame_count; }
    void    set_rel_range(int start_clip, int end_clip);
    void    set_source_path(const QString& src_path);
    void    set_trig_frame(uint32_t frame_num)            { trig_frame = frame_num; }

private slots:
    void    encoding_finished(void);
    void    process_started(void);
    void    stdout_ready(void);

    void    close_clicked(void);
    void    help_clicked(void);
    void    start_clicked(void);
    void    to_browser(void);

private:
    void        update_args(const QStringList& arg_list, bool no_args = true);

private:
    Ui::ExportDlg   *ui;
    QProcess        *transcoding_process;
    QString         status_string;

    uint32_t        clip_start;                             //!< User specified start of clip.
    uint32_t        clip_end;                               //!< User specified end of clip.
    QString         export_path;                            //!< The fully qualified path name for the exported video.
    QString         ffmpeg_path;                            //!< The fully qualified path name for the FFMPEG executable.
    uint32_t        num_frames;                             //!< Number of frames in the session.
    uint32_t        record_fps;                             //!< Number of frames per second for the recording.
    QString         source_path;                            //!< The fully qualified path to the source material.
    uint32_t        trig_frame;                             //!< Which frame is the trigger frame.

    const QStringList DEFAULT_ARG_LIST;                     //!< Define our default argument list.
};

#endif // EXPORT_DLG_H
