/*!
 * @file fi_camlist.cpp
 * @brief This provides the implementation for the fiCamList class.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include "fi_camlist.h"

#include <QDragEnterEvent>
#include <QDropEvent>
#include <QHostAddress>
#include <QMdiSubWindow>
#include <QMimeData>

#include <qendian.h>

#include "camera_dock.h"
#include "logger.h"

/*!
 * @brief Our fiCamList constructor.
 */
fiCamList::fiCamList( QWidget *parent ) :
    QListWidget( parent )
{
}

//--------------------------------------------------------------------
// Event Handlers
//--------------------------------------------------------------------

/*!
 * @brief Catch the drop event so we can allow a camera object to be dropped
 *        into our list widget.
 *
 * @param event     The drop event pointer.
 */
void fiCamList::dropEvent( QDropEvent *event )
{
    // Check for a Qt format.
    if ( event->mimeData()->hasFormat( "application/x-qabstractitemmodeldatalist" ))
    {
        QByteArray  encoded = event->mimeData()->data( "application/x-qabstractitemmodeldatalist" );
        QDataStream stream( &encoded, QIODevice::ReadOnly );

        // Parse the data. We're looking for an IP address entry.
        while ( !stream.atEnd() )
        {
            int row, col;
            QMap<int, QVariant> roleDataMap;

            // Pull the data into it's constituent parts.
            stream >> row >> col >> roleDataMap;

            // Is this the IP address?
            if ( col == CAMERA_DOCK::CD_IP_ADDR )
            {
                QHostAddress    cam_ip_addr;

                // Use the IP address to get the associated camera.
                cam_ip_addr.setAddress( roleDataMap.value(0).toString() );

                // Signal that we have an IP address of interest.
                emit camera_dropped( qFromBigEndian( cam_ip_addr.toIPv4Address() ));

                // We're done with this drop event.
                event->acceptProposedAction();
                break;
            }
        }
    }
}
