/*!
 * @file fi_countdown.h
 * @brief This is the header file for the fiCountDown class.
 *
 * Copyright 2020 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FICOUNTDOWN_H
#define FICOUNTDOWN_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <QWidget>
#include <QLCDNumber>

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------
class CameraMDI;

//--------------------------------------------------------------------
// Class
//--------------------------------------------------------------------
class FiCountDown : public QLCDNumber
{
    Q_OBJECT

public:
    explicit FiCountDown(QWidget *parent = nullptr);
    explicit FiCountDown(int secs, QWidget *parent = nullptr);
    ~FiCountDown();

    void setCamera(CameraMDI *camera_ptr);
    void setRepeat(bool enable)     { do_repeat = enable; }
    void setTime(int secs, bool autostart = false);

    void resume(int secs);
    void restart();
    void start();
    void stop();

    int startTime()     { return time_start; }
    int remainingTime() { return time_left; }

signals:
    void    expired();

protected:
    virtual void timerEvent(QTimerEvent *event);

private:
    void    initialize();

private:
    bool    do_repeat;          //!< True by default, automatically restarts the count down.

    int     time_start;         //!< Holds the original number of seconds.
    int     time_left;          //!< Holds the remaining number of seconds.
    int     timer_id;           //!< Timer ID.

    CameraMDI *camera_ptr;      //!< Associated camera.
};

#endif // FICOUNTDOWN_H
