/*!
 * @file fi_file.h
 * @brief A file utility class derived from QFile allowing enhancements
 * beyond the standard QFile functionality.
 *
 * Copyright 2023 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FIFILE_H
#define FIFILE_H

//-----------------------------------------------------------------------------
// Include Files
//-----------------------------------------------------------------------------
#include <QFile>
#include <QMap>
#include <QObject>

//--------------------------------------------------------------------
// Namespace: FI_FILE
//--------------------------------------------------------------------
namespace FI_FILE
{
//--------------------------------------------------------------------
// Constant, Macro and Type Definitions
//--------------------------------------------------------------------

//! Percent update signal frequency, defaults to every 10% change during copy.
const uint32_t COPY_PCT_UPDATE_PERIOD       = 10;

}   // End namespace (FI_FILE)

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

//--------------------------------------------------------------------
// Class Declaration: FiFile
//--------------------------------------------------------------------

class FiFile : public QFile
{
    Q_OBJECT
public:
    explicit FiFile(const QString& name, QObject *parent = nullptr);
    ~FiFile();

    static QMap<QString, bool> copyFileList;

    bool copyFile(const QString& newName, uint32_t pctUpdatePeriod = FI_FILE::COPY_PCT_UPDATE_PERIOD);

signals:
    void copyPercentComplete(int percentComplete, const QString& fileName);
};

#endif // FIFILE_H

