/*!
 * @file fi_histo_proc.h
 * @brief This is the header file for the fiHistoProc class.
 *
 * Copyright 2019 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_HISTO_PROC_H
#define FI_HISTO_PROC_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <QByteArray>
#include <QObject>
#include <QRect>
#include <QVector>

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

class QPixmap;

//--------------------------------------------------------------------
// Class Declaration
//--------------------------------------------------------------------
class fiHistoProc : public QObject
{
    Q_OBJECT

public:
    explicit fiHistoProc(QObject *parent = nullptr);

    void    calc(const QPixmap &my_pixels);
    void    calc(const QByteArray &my_pixels, int bpp, const QRect &img_rect);

    QRect   get_roi()                           { return histogram_roi; }

    const QVector<uint32_t> *get_mono() const   { return get_red(); }
    uint32_t get_sum_mono() const               { return get_sum_red(); }
    uint64_t get_sumsq_mono() const             { return get_sumsq_red(); }

    const QVector<uint32_t> *get_red() const    { return &histogram_red; }
    const QVector<uint32_t> *get_green() const  { return &histogram_green; }
    const QVector<uint32_t> *get_blue() const   { return &histogram_blue; }
    const QVector<uint32_t> *get_luminance() const  { return &histogram_luminance; }
    const QVector<int> *get_lum_map() const     { return &histo_lum_map; }

    uint32_t get_sum_red() const                { return sum_red; }
    uint64_t get_sumsq_red() const              { return sum_sq_red; }
    uint32_t get_sum_green() const              { return sum_green; }
    uint64_t get_sumsq_green() const            { return sum_sq_green; }
    uint32_t get_sum_blue() const               { return sum_blue; }
    uint64_t get_sumsq_blue() const             { return sum_sq_blue; }

    void    set_mono(bool is_mono)              { mono_mode = is_mono; }
    void    set_roi(const QRect roi)            { histogram_roi = roi; }

signals:
    void    fault();
    void    ready();

public slots:

private:
    bool                mono_mode;

    QRect               histogram_roi;                  //!< Region of Interest for calculating the histogram.
    QVector<uint32_t>   histogram_red;
    QVector<uint32_t>   histogram_green;
    QVector<uint32_t>   histogram_blue;
    QVector<uint32_t>   histogram_luminance;
    QVector<int>        histo_lum_map;

    uint32_t            sum_red;
    uint64_t            sum_sq_red;
    uint32_t            sum_green;
    uint64_t            sum_sq_green;
    uint32_t            sum_blue;
    uint64_t            sum_sq_blue;
};

#endif // FI_HISTO_PROC_H
