/*!
 * @file fi_image_buffer.h
 *
 * @brief A class that manages information about an image data
 * resource in a stream.
 *
 * Copyright 2020 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_IMAGE_BUFFER_H
#define FI_IMAGE_BUFFER_H
//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <memory>
#include "fi_mem_pool.h"

namespace FI_MEMPOOL
{

//--------------------------------------------------------------------
// Constants, Typedefs and Macros
//--------------------------------------------------------------------

//--------------------------------------------------------------------
// Class Declarations
//--------------------------------------------------------------------

//! The ImageBuffer class manages an image buffer describing its internal FiMemData object.
class FiImageBuffer
{
public:
    virtual ~FiImageBuffer();

    static std::unique_ptr<FI_MEMPOOL::FiImageBuffer> CreateImageBuffer();

    bool AttachImageData(FI_MEMPOOL::FiMemoryResourcePtr imageResourcePtrToAttach);

    uint32_t GetImageDataLen();
    const uint8_t *GetMemDataPtr();
    uint32_t  GetSequenceNumber();

    bool isFree();

    void LogMyDataId(const QString *moreInfoStr = nullptr);

    void PrepareToDestruct();

    FI_MEMPOOL::FiMemoryResourcePtr ReleaseImageData();
    uint32_t ReplaceImageBytes(uint32_t memBytesToSetLen, const uint8_t *memBytesToSetPtr);

    void SetSequenceNumber(uint32_t seqNumberToSet);

private:
    FiImageBuffer();

    //! This object is non-copyable and non-copy assignable.
    FiImageBuffer(const FiImageBuffer& i) = delete;
    FiImageBuffer& operator=(const FiImageBuffer& i) = delete;

    //! The image resource being managed if ownership taken by this object.
    FI_MEMPOOL::FiMemoryResourcePtr imageResourcePtr;

    uint32_t            seqNumber;          //!< Sequence number associated with memDataPtr.
    bool                warnIfDestructed;   //!< Flag when set will warn if destructed set true when created.
};



} /* End of namespace FI_MEMPOOL */

#endif // FI_IMAGE_BUFFER_H
