/*!
 * @file fi_journalctl.h
 * @brief This is the header file for the FiJournalCtl class.
 *
 * Copyright 2020 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_JOURNALCTL_H
#define FI_JOURNALCTL_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <QList>
#include <QObject>
#include <QString>
#include <QStringList>

#include <memory>

namespace FI_JOURNALCTL
{
//--------------------------------------------------------------------
// Constant, Typedefs and Macros
//--------------------------------------------------------------------

/*!
 * @brief The SSH_SETTINGS structure is used to pass required information to
 *        the FiJournalCtl object. It is only necessary if the camera is remote.
 */
struct SSH_SETTINGS
{
    QString hostname;           //!< The host name or IP address.
    QString username;           //!< The user name to use for SSH.
    QString crypt_info;         //!< The passphrase to use.
};

} // End of FI_JOURNALCTL


//--------------------------------------------------------------------
// Class Declaration
//--------------------------------------------------------------------

class FiJournalCtl : public QObject
{
    Q_OBJECT

public:
    explicit FiJournalCtl(QObject *parent = nullptr);
    explicit FiJournalCtl(QObject *parent, const FI_JOURNALCTL::SSH_SETTINGS *ssh_info);
    ~FiJournalCtl();

    void close();
    const QString errorStr();

    bool isCreated()                        { return (jc_conn.get() != nullptr); }
    bool isRemote();
    bool isRoot()                           { return need_sudo; }
    bool isRunning();

    void setAdditionalArgs(const QStringList& args) { extra_args = args; }
    void setFollow(bool do_follow)          { follow = do_follow; }
    void setIdentifiers(const QStringList& ids);
    void setUseSudo(bool do_sudo)           { need_sudo = do_sudo; }

    void run();
    QString runAndWait(const QString& cmd, const QStringList& args);

signals:
    void dataAvailable(const QString& log_data);

public slots:
    void processData(const QString& log_data);

private:
    std::unique_ptr<QObject> jc_conn;
    QString error_info;                                         //!< Text representing what might have gone wrong.

    bool is_remote;
    bool follow;
    bool need_sudo;

    QStringList extra_args;
    QStringList id_list;
};

#endif // FI_JOURNALCTL_H
