/*!
 * @file fi_label.h
 * @brief This is the header file for the fiLabel class.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_LABEL_H
#define FI_LABEL_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <QWidget>
#include <QLabel>
#include <QResizeEvent>

//! Need to create a QLabel subclass so we can scale pixmaps maintaining
//! the aspect ratio.
class fiLabel : public QLabel
{
    Q_OBJECT

public:
    explicit fiLabel(QWidget *parent = NULL, Qt::WindowFlags flags = Qt::WindowFlags()) : QLabel(parent, flags) { maintainAspect = false; }

    void keepAspect(bool do_keep)     { maintainAspect = do_keep; }
    bool isAspectMaintained(void)     { return maintainAspect; }

public slots:
    void setPixmap(const QPixmap& new_pixmap)
    {
        // Do we want to keep the aspect ratio?
        if (maintainAspect)
        {
            int w = width();
            int h = height();

            // Save the unscaled pixmap for later.
            unscaledPixmap = new_pixmap;

            // Pass it on while maintaining the aspect ratio.
            QLabel::setPixmap(new_pixmap.scaled(w, h, Qt::KeepAspectRatio));
        }
        else
        {
            // Just pass it on.
            QLabel::setPixmap(new_pixmap);
        }
    }

protected:
    void resizeEvent(QResizeEvent *event)
    {
        // Are we worried about the pixmap?
        if (maintainAspect && !unscaledPixmap.isNull())
        {
            // Update our pixmap.
            QLabel::setPixmap(unscaledPixmap.scaled(event->size().width(), event->size().height(), Qt::KeepAspectRatio));
        }

        // Pass it up to the parent.
        QLabel::resizeEvent(event);
    }

private:
    bool    maintainAspect;
    QPixmap unscaledPixmap;
};

#endif // FI_LABEL_H
