/*!
 * @file fi_loadcap.h
 *
 * @brief This is the header file for the CAP loading dialog class.
 *
 * Copyright 2020 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_LOADCAP_H
#define FI_LOADCAP_H

//-----------------------------------------------------------------------------
// Include Files
//-----------------------------------------------------------------------------

#include "fi_progress_dialog.h"

//-----------------------------------------------------------------------------
// FiLoadCap Class Declaration
//-----------------------------------------------------------------------------

class fiLoadCaptureDlg : public fiProgressDialog
{
    Q_OBJECT
    explicit fiLoadCaptureDlg(QWidget *parent = nullptr, Qt::WindowFlags flags = Qt::WindowFlags());

public:
    ~fiLoadCaptureDlg();

    static std::unique_ptr<fiLoadCaptureDlg> CreateLoadCaptureDlg(const QString& titlePrefixString,
                                                                  QWidget *parent = nullptr);

    void enableCleanup(bool do_enable)          { self_cleanup = do_enable; }
    void setFilePath(const QString& file_path)  { media_path = file_path; }
    const QString& getFilePath()                { return media_path; }

signals:
    void load_failed();
    void loading_finish();

public slots:
    virtual int exec();

private slots:
    virtual void cancelDialog();

    void stateTransition();
    void streamIsPaused();
    void userCanceledLoad();

    void read_complete(uint32_t ip_addr, uint32_t reg_addr);
    void write_complete(uint32_t ip_addr, uint32_t reg_addr);

private:
    void updateLoadProgress();

private:
    int cur_state;
    QString media_path;
    bool self_cleanup;
};

#endif // FI_LOADCAP_H
