/*!
 * @file fi_pixmap.h
 * @brief A pixmap class with enhancements beyond the standard QPixmap.
 *
 * Copyright 2014 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_PIXMAP_H
#define FI_PIXMAP_H

//-----------------------------------------------------------------------------
// Include Files
//-----------------------------------------------------------------------------

#include <QPixmap>
#include <stdint.h>

#include "fi_saver.h"

//--------------------------------------------------------------------
// Class Declaration: fiPixmap
//--------------------------------------------------------------------
class fiPixmap : public QPixmap
{
public:
    fiPixmap();
    fiPixmap(const QPixmap& src_pixmap);
    explicit fiPixmap(int width, int height);
    explicit fiPixmap(const QString& fileName, const char *format = nullptr, Qt::ImageConversionFlags flags = Qt::AutoColor);
    ~fiPixmap();

    void    apply_lookup(const uint8_t *lookup_r = nullptr, const uint8_t *lookup_g = nullptr, const uint8_t *lookup_b = nullptr);
    void    apply_matrix(const double ccm[][4]);
    void    auto_wb(double *r_gain, double *g_gain, double *b_gain);
    bool    is_raw(const QString& file_type);
    bool    load(const QString& fileName, const char *format = nullptr, Qt::ImageConversionFlags flags = Qt::AutoColor);
    bool    load_from_buf(QByteArray& buf, FAS_VIDEO::VIDEO_CODEC fvCodec);
    bool    load_raw(const QString& fileName, const char *format = nullptr, Qt::ImageConversionFlags flags = Qt::AutoColor);
    void    save_image(QByteArray *dest_buf, FI_SAVER::IMAGE_TYPE imageType);

    void    set_ccm(double ccm[][4]);
    void    set_gamma(double gamma_value)           { gamma = gamma_value; }
    void    set_jpeg_quality(int quality);
    void    set_sensor_type(uint32_t sensor_type)   { this->sensor_type = sensor_type; }
    void    set_whitebal(int new_value, double r_wb = 1.0, double g_wb = 1.0, double b_wb = 1.0)             { whitebal = new_value; r_wb_gain = r_wb; g_wb_gain = g_wb; b_wb_gain = b_wb; }

private:
    int     jpeg_quality;
    bool    ccm_updated;
    double  ccm[3][4];
    double  gamma;
    QImage  *raw_rgb_image;

    int     whitebal;
    double  r_wb_gain;
    double  g_wb_gain;
    double  b_wb_gain;
    uint32_t sensor_type;
};

#endif // FI_PIXMAP_H
