/*!
 * @file fi_progbar.h
 * @brief This is the header file for the record progress control.
 *        It provides user feedback during recording of live video.
 *
 * Copyright 2014 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_PROGBAR_H
#define FI_PROGBAR_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <stdint.h>
#include <QWidget>
#include <QTimer>

namespace Ui
{
class fiProgBar;
}

namespace FI_PROGBAR
{
//--------------------------------------------------------------------
// Constant, Macro and Type Definitions
//--------------------------------------------------------------------

//! The polling period for record progress information.
const int       REC_POLL_PERIOD         = 500;

}   // End of namespace FI_PROGBAR.

//--------------------------------------------------------------------
// Class Definition
//--------------------------------------------------------------------
class fiProgBar : public QWidget
{
    Q_OBJECT

public:
    explicit fiProgBar(QWidget *parent = 0);
    ~fiProgBar();

    int     get_trigger_frame()                 { return trigger_frame; }
    bool    polling_is_active();

    void    reset();

    void    set_current_frame(int frame_num);
    void    set_num_frames(int num_frames);
    void    set_trigger(int trig_frame);

    void    start_polling(int polling_period = FI_PROGBAR::REC_POLL_PERIOD);
    void    stop_polling();

signals:
    void    time_to_update();

private:
    Ui::fiProgBar *ui;

    int     total_frame_count;
    int     trigger_frame;
    QTimer  progress_poll_timer;
    bool    toggle_style;

    void    update_label();
};

#endif // FI_PROGBAR_H
