/*!
 * @file fi_rawfile.h
 * @brief This is the header file for the fiRawFile class.
 *
 * Copyright 2014 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_RAWFILE_H
#define FI_RAWFILE_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <QObject>
#include <stdint.h>

#include "fi_rawdrive.h"

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

class QByteArray;
class QFile;

//--------------------------------------------------------------------
// Class Declaration
//--------------------------------------------------------------------
class fiRawFile : public fiRawDrive
{
    Q_OBJECT

public:
    explicit fiRawFile(QObject *parent = 0);
    ~fiRawFile();

    bool                getFileName(QString& raw_file_name);

    virtual void        close() override;
    virtual uint32_t    getFrameCount() override;
    virtual bool        open(const QString& cap_uri) override;
    virtual bool        readFrame(uint32_t frame_num, bool do_correction, const uint8_t *lookup_bcg,
                                  bool force8BitMono, FAS_VIDEO::VIDEO_CODEC *fvCodecPtr, QByteArray *dest_buf) override;
    virtual bool        readFrame(uint32_t frame_num, bool do_correction, fiPixmap *dest_pixmap) override;
    virtual uint32_t    readPerFrameMetadata(QByteArray& raw_buffer) override;
    virtual bool        readPmMetadata(struct pm_metadata_type *metadata_ptr) override;
    virtual bool        readRawImage(uint32_t frame_num, QByteArray& raw_image) override;
    virtual bool        recoverCT() override;

protected:
    uint32_t    convertToAbsFrameNum(uint32_t frame_num, bool absolute);
    uint32_t    getFirstFrame();
    uint32_t    get_skip_count();

private:
    bool    readFrameMetadata(uint32_t frame_num, QByteArray& event_data);

private:
    QFile   *root_file;         //!< Our main (root) CAP file.
    QFile   *span_file;         //!< If the capture was large enough it spans into this file.
};

#endif // FI_RAWFILE_H
