/*!
 * @file fi_sensor.h
 * @brief This is the header file for the fiSensor class.
 *
 * Copyright 2014 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_SENSOR_H
#define FI_SENSOR_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <QObject>
#include <QRect>
#include <stdint.h>

namespace FI_SENSOR
{
//--------------------------------------------------------------------
// Constant, Macro and Type Definitions
//--------------------------------------------------------------------

const int   DEFAULT_HEIGHT_MOD      = 2;
const int   DEFAULT_WIDTH_MOD       = 4;

// This macro is how we create condensed tag information.
#define SENSOR_ID( a, b, c, d )         ((((uint32_t)(a))<<24) | (((uint32_t)(b))<<16) | (((uint32_t)(c))<<8)  | ((uint32_t)(d)))
const uint32_t  SENSOR_TYPE_UNKNOWN             = SENSOR_ID('U', 'N', 'K', 'N');
const uint32_t  SENSOR_TYPE_LUX13HS_MONO        = SENSOR_ID('X', '3', 'H', 'M');
const uint32_t  SENSOR_TYPE_LUX13HS_COLOR       = SENSOR_ID('X', '3', 'H', 'C');
const uint32_t  SENSOR_TYPE_LUX160_MONO         = SENSOR_ID('X', '6', '0', 'M');
const uint32_t  SENSOR_TYPE_LUX160_COLOR        = SENSOR_ID('X', '6', '0', 'C');
const uint32_t  SENSOR_TYPE_LUX19HS_MONO        = SENSOR_ID('X', '9', 'H', 'M');
const uint32_t  SENSOR_TYPE_LUX19HS_COLOR       = SENSOR_ID('X', '9', 'H', 'C');
const uint32_t  SENSOR_TYPE_LUX2100_MONO        = SENSOR_ID('X', '2', '1', 'M');
const uint32_t  SENSOR_TYPE_LUX2100_COLOR       = SENSOR_ID('X', '2', '1', 'C');
const uint32_t  SENSOR_TYPE_LUPA1300_MONO       = SENSOR_ID('L', '1', '3', 'M');
const uint32_t  SENSOR_TYPE_LUPA1300_COLOR      = SENSOR_ID('L', '1', '3', 'C');
const uint32_t  SENSOR_TYPE_LINCE5M_MONO        = SENSOR_ID('A', 'L', '5', 'M');
const uint32_t  SENSOR_TYPE_LINCE5M_COLOR       = SENSOR_ID('A', 'L', '5', 'C');
const uint32_t  SENSOR_TYPE_GENERIC_MONO        = SENSOR_ID('G', 'E', 'N', 'M');
const uint32_t  SENSOR_TYPE_GENERIC_COLOR       = SENSOR_ID('G', 'E', 'N', 'C');

// A class specific forward declaration.
class fiSensorPrivate;

}   // End of namespace FI_SENSOR.

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

class CameraMDI;

//--------------------------------------------------------------------
// Class Definition
//--------------------------------------------------------------------
class fiSensor : public QObject
{
    Q_OBJECT

public:
    explicit fiSensor(QObject *parent = nullptr);
    ~fiSensor();

    uint32_t    get_type();
    bool        is_color();
    uint32_t    max_frame_rate(QRect *p_roi, uint32_t bit_depth);
    int         max_pixel_depth();
    QRect       max_roi(uint32_t bit_mode);
    bool        opts_avail();
    void        set_options(uint32_t opt_value);
    bool        supports_adv_cal();
    bool        supports_pixel_fpn();
    bool        supports_sensor_fpn();
    bool        supports_video_trigger();

    int height_mod();
    int width_mod();

private slots:
    void    handle_unsol_msg(uint32_t ip_addr, uint32_t reg_addr, uint32_t reg_value);
    void    init_query();
    void    read_complete(uint32_t ip_addr, uint32_t reg_addr);

private:
    void    process_sensor_type(uint32_t sensor_type);

private:
    CameraMDI   *mdi_parent;                //!< Our parent object, in it's true colors.
    FI_SENSOR::fiSensorPrivate  *priv_ptr;  //!< Our sensor specific object.
};

#endif // FI_SENSOR_H
