/*!
 * @file fi_sensor_priv.h
 * @brief This is the header file for the fiSensorPrivate class.
 *
 * Copyright 2014 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_SENSOR_PRIV_H
#define FI_SENSOR_PRIV_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <QVersionNumber>
#include "fi_sensor.h"

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

class QRect;

namespace FI_SENSOR
{
/*!
 * @brief The fiSensorPrivate class.
 */
class fiSensorPrivate
{
public:
    fiSensorPrivate(fiSensor *parent = nullptr, uint32_t sensor_id = FI_SENSOR::SENSOR_TYPE_UNKNOWN);
    virtual ~fiSensorPrivate();

    virtual bool        is_color() = 0;
    virtual uint32_t    max_frame_rate(QRect *p_roi, uint32_t bit_depth) = 0;
    virtual int         max_pixel_depth() = 0;
    virtual QRect       max_roi(uint32_t bit_mode) = 0;
    virtual bool        opts_avail() = 0;
    virtual void        set_options(uint32_t opt_value) = 0;
    virtual bool        supports_adv_cal()          { return false; }
    virtual bool        supports_pixel_fpn()        { return false; }
    virtual bool        supports_sensor_fpn()       { return false; }
    virtual bool        supports_video_trigger()    { return false; }

    virtual uint32_t    get_type()    { return sensor_type; }
    virtual uint16_t    max_height()  { return sensor_max_height; }
    virtual uint16_t    max_width()   { return sensor_max_width; }
    virtual uint16_t    min_height()  { return sensor_min_height; }
    virtual uint16_t    min_width()   { return sensor_min_width; }
    virtual int         height_mod()  { return FI_SENSOR::DEFAULT_HEIGHT_MOD; }
    virtual int         width_mod()   { return FI_SENSOR::DEFAULT_WIDTH_MOD; }
    virtual void        reg_update(uint32_t reg_addr, uint32_t reg_value);

protected:
    fiSensor    *my_parent;                 //!< Pointer to our parent object.

    uint32_t    sensor_max_frame_rate;      //!< Maximum frame rate for the sensor.
    uint16_t    sensor_max_height;          //!< Height of the sensor, in pixels.
    uint16_t    sensor_max_width;           //!< Width of the sensor, in pixels.
    uint16_t    sensor_min_height;          //!< Minimum height ROI of the sensor, in pixels.
    uint16_t    sensor_min_width;           //!< Minimum width ROI of the sensor, in pixels.
    uint32_t    sensor_type;                //!< One of the FI_SENSOR::SENSOR_ID values above.
    QVersionNumber icm_version;             //!< The version of the ICM module.
    QVersionNumber fpga_version;            //!< The version of the FPGA module.
};

}   // End of namespace FI_SENSOR.

#endif // FI_SENSOR_PRIV_H
