/*!
 * @file fi_slider.h
 * @brief A slider class with enhancements beyond the standard QSlider.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_SLIDER_H
#define FI_SLIDER_H

//-----------------------------------------------------------------------------
// Include Files
//-----------------------------------------------------------------------------

#include <QColor>
#include <QList>
#include <QSlider>
#include <QStyle>

//--------------------------------------------------------------------
// Namespace: FI_SLIDER
//--------------------------------------------------------------------
namespace FI_SLIDER
{
//--------------------------------------------------------------------
// Constant, Macro and Type Definitions
//--------------------------------------------------------------------

//! Period, in milliseconds, we'll update the current position information when the user is dragging the "thumb".
const int   SCRUB_UPDATE                    = 250;

}   // End namespace (FI_SLIDER)

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

//--------------------------------------------------------------------
// Class Declaration: fiSlider
//--------------------------------------------------------------------
class fiSlider : public QSlider
{
    Q_OBJECT

public:
    explicit fiSlider(QWidget *parent = nullptr);
    explicit fiSlider(Qt::Orientation orientation, QWidget *parent = nullptr);
    ~fiSlider();

    QColor  get_event_color() const                 { return event_color; }
    const QList<int>& markers() const;

    int     getThrottle()                           { return update_period; }

    void    setEventColor(const QColor& newColor);
    void    setEventMarkers(const QList<int>& newMarkers);
    void    setThrottle(int new_update_period)      { update_period = new_update_period; }

    bool    throttleIsActive()                      { return (throttle_id != 0); }

signals:
    void    released();
    void    valueSlowChanged(int);

protected:
    virtual void    paintEvent(QPaintEvent *event);
    virtual void    timerEvent(QTimerEvent *event);

private slots:
    void    handleSliderPressed();
    void    handleSliderReleased();

private:
    void    initClass(void);

private:
    int     throttle_id;                        //!< The timer ID used when throttling is enabled.
    int     update_period;                      //!< The time between positional updates, when throttling is enabled.

    QColor      event_color;                    //!< The color we paint our event markers with.
    QList<int>  event_markers;                  //!< The event markers.
};

#endif // FI_SLIDER_H
