/*!
 * @file fi_spinbox.h
 * @brief This is the header file for the fiSpinBox class.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_SPINBOX_H
#define FI_SPINBOX_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <QWidget>
#include <QSpinBox>

//! Need to create a QSpinBox subclass so we can force the value displayed
//! to have leading zeros.
class fiSpinBox : public QSpinBox
{
    Q_OBJECT

public:
    fiSpinBox( QWidget *parent ) : QSpinBox( parent ) { field_width = 0; }

    void set_field_width( int new_width )   { field_width = new_width; }

protected:
    virtual QString textFromValue( int value ) const
    {
        return QString::fromUtf8( "%1" ).arg( value, field_width, 10, QLatin1Char( '0' ));
    }

private:
    int     field_width;          //! The number of characters for the field.
};

#endif // FI_SPINBOX_H
