/*!
 * @file fi_splinewidget.h
 * @brief This is the header file for the Spline display widget.
 *
 * This widget is derived from the work found here:
 *      Widget: https://github.com/pyzhangxiang/qt-curve-editor
 *      Spline library: http://people.sc.fsu.edu/~jburkardt/c_src/spline/spline.html
 *
 * Copyright 2015 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef __FI_SPLINEWIDGET_H__
#define __FI_SPLINEWIDGET_H__

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <QObject>
#include <QWidget>
#include <vector>
#include <stdint.h>
#include "libspline/aaCurve.h"

//-----------------------------------------------------------------------------
// Class Forward Declarations
//-----------------------------------------------------------------------------
class QwtPlot;
class QwtPlotPicker;

//--------------------------------------------------------------------
// Class Declaration
//--------------------------------------------------------------------
class fiSplineWidget : public QWidget
{
    Q_OBJECT

public:
    explicit fiSplineWidget(QWidget *parent = 0);
    explicit fiSplineWidget(double deltaT, QWidget *parent = 0);
    ~fiSplineWidget(void);

    void allow_zoom(bool do_zoom)             { zoom_ok = do_zoom; }
    int max_knot_count(void)                  { return max_knots; }
    void set_increment(double deltaT)         { delta_t = deltaT; }
    void set_spline(std::shared_ptr<aaAaa::aaSpline> sdata);
    void set_max_knot_count(int count)        { max_knots = count; }

    int get_data(int step, QVector<double>& lut);

signals:
    void selectValuesChanged(float t, float v);
    void switchType(int new_type);

protected:
    void    mouseReleaseEvent(QMouseEvent *event);
    void    resizeEvent(QResizeEvent *event);
    void    contextMenuEvent(QContextMenuEvent *event_ptr);

private:
    int     checkSelected(const QPointF& point);

    void    add_marker(int index);
    void    del_marker(int index);
    int     find_marker(int index);

    void init_controls(void);
    void update_spline(void);

private slots:
    void marker_moved(const QPointF& pos);
    void marker_selected(const QPointF& pos);

private:
    int             ctrl_point_sel;         //!< Index of the control point currently selected.
    int             marker_index;           //!< The corresponding marker for the selected control point.
    int             max_knots;              //!< The maximum number of knots to support, or -1 for no limit.

    std::shared_ptr<aaAaa::aaSpline> spline_data;   //!< The curve data.
    double          delta_t;                //!< Resolution of the curve (distance between points).

    int             widget_width;           //!< The width of the widget.
    int             widget_height;          //!< The height of the widget.
    bool            zoom_ok;                //!< Control flag to allow/disallow user zoom.

    QList<QwtPlot *>        plot_curves;    //!< List of plots showing the signals values.
    QwtPlotPicker          *plot_picker;    //!< Picker object for the plots.
};

#endif // __FI_SPLINEWIDGET_H__
