/*!
 * @file fi_streamsocket.h
 * @brief This header file declares the FiStreamSocket class.
 *
 * Copyright 2018 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_STREAMSOCKET_H
#define FI_STREAMSOCKET_H

//--------------------------------------------------------------------
// Include Files
//--------------------------------------------------------------------

#include <QObject>
#include <QTcpSocket>

//--------------------------------------------------------------------
// FiStreamSocket class.
//--------------------------------------------------------------------

class FiStreamSocket : public QObject
{
    Q_OBJECT

public:
    explicit FiStreamSocket(QObject *parent = nullptr);
    ~FiStreamSocket();

    void connect_cam(const QHostAddress& host, quint16 port);
    qint64 data_available();
    int get_last_err(QString& err_msg)  {err_msg = last_errstr; return last_errcode;}
    quint16 get_port()                  {return stream_port;}
    qint64 read(uint8_t *buffer_ptr, qint64 read_len);
    QByteArray read(qint64 max_size);
    QByteArray readAll();

    void quit();

signals:
    void error();                   //!< Indicates we got an error.
    void ready();                   //!< Indicates when we're initialized and ready to go.
    void data_ready();              //!< Indicates there is data pending.
    void finished();                //!< Indicates we're done.

public slots:
    void connected();
    void disconnected();
    void errorOccurred(QAbstractSocket::SocketError socketError);
    void read_pending();

private:
    QTcpSocket *tcp_socket;         //!< The actual socket.
    quint16 stream_port;            //!< Our assigned port.

    int last_errcode;               //!< Code describing what happened.
    QString last_errstr;            //!< String describing what happened.
};

#endif // FI_STREAMSOCKET_H
