/*!
 * @file fi_stringspinbox.h
 * @brief A spinbox which uses strings instead of numbers, heavily derived from the QxtSpanSlider which
 *        no longer appears to be support and won't build under Qt5.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */
#ifndef FI_STRING_SPINBOX_H
#define FI_STRING_SPINBOX_H

//-----------------------------------------------------------------------------
// Include Files
//-----------------------------------------------------------------------------
#include <QWidget>
#include <QSpinBox>
#include <QString>
#include <QStringList>

//--------------------------------------------------------------------
// Class Declaration: fiStringSpinBox
//--------------------------------------------------------------------
class fiStringSpinBox : public QSpinBox
{
    Q_OBJECT

public:
    explicit fiStringSpinBox(QWidget *parent = 0);
    virtual ~fiStringSpinBox();

    const QStringList& strings(void) const;
    void setStrings(const QStringList& strings);

    virtual void fixup(QString& input) const;
    virtual QValidator::State validate(QString& input, int& pos) const;

signals:
    void    value_changed(void);

protected:
    virtual QString textFromValue(int value) const;
    virtual int valueFromText(const QString& text) const;

private:
    int startsWith(const QString& start, QString& string) const;

private:
    QStringList string_list;                        //!< Our list of strings.
};

#endif // FI_STRING_SPINBOX_H
