/*!
 * @file fi_switchbutton.h
 * @brief This is the header file for the fiSwitchButton class.
 *
 * Copyright 2019 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 *
 * Derived extensively from: https://stackoverflow.com/questions/14780517/toggle-switch-in-qt/38102598.
 *
 */

#ifndef FI_SWITCHBUTTON_H
#define FI_SWITCHBUTTON_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <QWidget>

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

class QKeyEvent;
class QLabel;
class QPropertyAnimation;
class QResizeEvent;

//--------------------------------------------------------------------
// Class declaration: fiTableView
//--------------------------------------------------------------------

class fiSwitchButton : public QWidget
{
    Q_OBJECT
    Q_DISABLE_COPY(fiSwitchButton)

public:
    enum Style
    {
        YESNO,
        ONOFF,
        BOOL,
        EMPTY
    };

public:
    explicit fiSwitchButton(QWidget *parent = nullptr, Style style = Style::ONOFF);
    ~fiSwitchButton() override;

    //-- QWidget methods
    void mousePressEvent(QMouseEvent *) override;
    void paintEvent(QPaintEvent *event) override;
    void setEnabled(bool);

    //-- Events
    void keyReleaseEvent(QKeyEvent *event) override;
    void resizeEvent(QResizeEvent *event) override;

    //-- Setters
    void setDuration(int time);
    void setStyle(Style style);
    void setValue(bool flag);

    //-- Getters
    Style style() const;
    bool value() const;

signals:
    void valueChanged(bool newvalue);

private:
    class SwitchCircle;
    class SwitchBackground;
    void _update();

private:
    bool _value;
    int  _duration;
    Style _style;

    QColor _pencolor;
    QColor _offcolor;
    QColor _oncolor;
    int    _tol;
    int    _borderradius;

    // This order for definition is important (these widgets overlap)
    QLabel           *_labeloff;
    SwitchBackground *_background;
    QLabel           *_labelon;
    SwitchCircle     *_circle;

    bool _enabled;

    QPropertyAnimation *__btn_move;
    QPropertyAnimation *__back_move;
};

class fiSwitchButton::SwitchBackground : public QWidget
{
    Q_OBJECT
    Q_DISABLE_COPY(SwitchBackground)

public:
    explicit SwitchBackground(QWidget *parent = nullptr, QColor color = QColor(Qt::gray), bool rect = false);
    ~SwitchBackground() override;

    //-- QWidget methods
    void paintEvent(QPaintEvent *event) override;
    void setEnabled(bool);

    //-- Events
    void resizeEvent(QResizeEvent *event) override;

private:
    bool _rect;
    bool _enabled;
    int _borderradius;
    QColor _color;
};


class fiSwitchButton::SwitchCircle : public QWidget
{
    Q_OBJECT
    Q_DISABLE_COPY(SwitchCircle)

public:
    explicit SwitchCircle(QWidget *parent = nullptr, QColor color = QColor(255, 255, 255), bool rect = false);
    ~SwitchCircle() override;

    //-- QWidget methods
    void paintEvent(QPaintEvent *event) override;
    void setEnabled(bool);

    //-- Events
    void resizeEvent(QResizeEvent *event) override;

private:
    bool _rect;
    bool _enabled;
    int _borderradius;
    QColor _color;
};

#endif // FI_SWITCHBUTTON_H
