/*!
 * @file fi_userdoc_dialog.h
 * @brief This is the header file for the fiUserDocDialog class.
 *
 * Copyright 2022 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */
#ifndef FI_USERDOC_DIALOG_H
#define FI_USERDOC_DIALOG_H

#include <QDialog>
#include <QDir>
#include <QFile>
#include <QMessageBox>
#include <QNetworkAccessManager>
#include <QNetworkReply>
#include <QStandardPaths>
#include <QtNetwork>
#include <QUrl>

namespace Ui
{
class fiUserDocDialog;
}

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

class fiProgressDialog;

//--------------------------------------------------------------------
// Class Declaration
//--------------------------------------------------------------------
class fiUserDocDialog : public QDialog
{
    Q_OBJECT

public:
    explicit fiUserDocDialog(QWidget *parent = nullptr);
    ~fiUserDocDialog();

signals:
    void docDownloadFailed();
    void docDownloadFinished();
    void progress(qint64 bytesReceived, qint64 bytesTotal);

private slots:
    void doBrowse();
    void doDownloadEnable(bool checked);

    void doDownload();

    void doDocDownloadCanceled();
    void doDocDownloadFailed();
    void doDocDownloadFinished();

    void httpError(QNetworkReply::NetworkError errorCode);
    void httpFinished();
    void httpReadyRead();

    void httpProgress(qint64 bytesReceived, qint64 bytesTotal);

private:
    Ui::fiUserDocDialog *ui;

    static const QString DOC_DOWNLOAD_GROUP;             //!< The QSettings group tag for document downloads.
    static const QString DOC_DOWNLOAD_SERVER_KEY;        //!< The QSettings key for the update server URL. If the entry doesn't exist, then the UpdateServerUrl value is used.
    static const QString DOC_DOWNLOAD_MANUAL_DIR_KEY;    //!< The QSettings key for the user manual directory on update server.
    static const QString DOC_DOWNLOAD_PATH_KEY;          //!< The QSettings key for the local path location.

    static const QString DOC_DOWNLOAD_SERVER;
    static const QString DOC_DOWNLOAD_MANUAL_DIR;
    static const QString MANUAL_FASMOTION;
    static const QString MANUAL_HS;
    static const QString MANUAL_HS_QSG;
    static const QString MANUAL_IL;
    static const QString MANUAL_IL_QSG;
    static const QString MANUAL_TS;
    static const QString MANUAL_TS_QSG;

    void downloadADocument(const QString manualName);
    void docDownloadCompleted(bool completedOk);

    void setEnabledState(bool enabled);
    bool startHTTPDownload(const QUrl& requestedUrl);

    QList<QString> downloadList;

    QString downloadServerUrl;
    QString downloadPath;
    QString downloadStatus;

    int downloadErrCode;

    QFile *downloadFile;

    std::unique_ptr<fiProgressDialog> progressDialog;   //!< A simple progress dialog for operational status.

    std::unique_ptr<QNetworkAccessManager> nam;
    QNetworkReply *netReply;
};

#endif // FI_USERDOC_DIALOG_H
