/*!
 * @file force_ip.h
 * @brief Header for the Network configuration dialog.
 *
 * It takes the new settings and applies them to the camera. Allowing changes to
 * IP address, etc.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FORCE_IP_H
#define FORCE_IP_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <QDialog>
#include "fi_comm.h"

#include <QtEndian>
#include <QtNetwork>

#include "mac_ctrl.h"

namespace Ui
{
    class ForceIPDialog;
}

//--------------------------------------------------------------------
// The ForceIPDialog class definition
//--------------------------------------------------------------------
class ForceIPDialog : public QDialog
{
    Q_OBJECT
    
public:
    explicit ForceIPDialog(QWidget *parent = 0);
    ~ForceIPDialog();

    bool            dhcp_is_enabled( void );

    QHostAddress    &get_ip( void )             { return user_ip; }
    QHostAddress    &get_net_mask( void )       { return user_net_mask; }
    QHostAddress    &get_gw( void )             { return user_gw; }
    const uint8_t   *get_mac( void );

    void            allow_mac_edit( bool do_allow = true );
    void            set_dhcp_allowed( bool is_allowed );
    void            set_info( const FI_COMM::FI_CAMERA_INFO *cam_info );

private slots:
    void    accept( void );
    void    dhcp_toggled( bool checked );

private:
    Ui::ForceIPDialog *ui;

    QHostAddress        user_ip;
    QHostAddress        user_net_mask;
    QHostAddress        user_gw;
    uint8_t             user_mac[ MacCtrl::QTUTL_MAC_SIZE ];

    void    set_ip( uint32_t ip_addr );
    void    set_netmask( uint32_t net_mask );
    void    set_gateway( uint32_t gateway_addr );
    void    set_mac( const uint8_t *mac_addr );

    void    error_msg( const QString &err_str );
};

#endif // FORCE_IP_H
