/*!
 * @file format_dlg.h
 * @brief This is the header file for the FormatDlg class.
 *
 * Copyright 2018 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FORMAT_DLG_H
#define FORMAT_DLG_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <QDialog>
#include <stdint.h>

//--------------------------------------------------------------------
// Forward declarations
//--------------------------------------------------------------------
class fiSwitchButton;

namespace Ui
{
class FormatDlg;
}

class FormatDlg : public QDialog
{
    Q_OBJECT

public:
    const int FAT_MAX_VOLUME_LEN        = 11;
    const int DEFAULT_MAX_VOLUME_LEN    = 16;
    static const QString EXT_FMT_SERIES_3_TXT;
    static const QString EXT_FMT_SERIES_HS_TXT;

public:
    explicit FormatDlg(QWidget *parent = nullptr);
    ~FormatDlg();

    void isSeries3(bool series3 = true);

public slots:
    virtual void accept();
    virtual int exec();

public:
    uint32_t media_type;
    uint32_t format_type;
    QString vol_label;
    bool internal_ssd;
    bool lrmode;
    bool sanitize;

private slots:
    void do_sanitize(bool enable);
    void format_FAT();
    void format_EXFAT();
    void format_EXT();
    void format_FILR();
    void format_NTFS();

private:
    Ui::FormatDlg *ui;

    bool series3;               // True if the camera is series3 camera.
    fiSwitchButton *sw_erase;   // The erase Yes/No button.
};

#endif // FORMAT_DLG_H
