/*!
 * @file gige_socket.h
 * @brief This header file declares the FCPSocket class.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef GIGE_SOCKET_H
#define GIGE_SOCKET_H

//--------------------------------------------------------------------
// Include Files
//--------------------------------------------------------------------

#include <QUdpSocket>
#include <errno.h>

#include "gige_msg.h"

//--------------------------------------------------------------------
// GigESocket class.
//--------------------------------------------------------------------

class GiGESocket : public QUdpSocket
{
    Q_OBJECT

public:
    explicit GiGESocket(QObject *parent = nullptr, uint32_t port_id = 0);
    ~GiGESocket();

    static const uint32_t  MAX_IMAGE_SIZE;

    void setLocalAddress(const QHostAddress& address)     { QUdpSocket::setLocalAddress(address); }

    void        set_port(int new_port)        { msg_port = static_cast<uint32_t>(new_port); }
    uint32_t    get_port()                { return msg_port; }

    int     get_last_err(QString& err_msg);

    int     send_msg(const QByteArray& msg_out, const QHostAddress& dest_addr);

public slots:
    void    quit();                 //!< Shutdown the socket.
    void    start();                //!< Start up the socket.

signals:
    void    error();                //!< Indicates we got an error.
    void    finished();             //!< Indicate when we're done.
    void    started();              //!< Indicated when we're initialized and ready to go.

private:
    uint32_t        msg_port;       //!< Our assigned port.

    int             last_errcode;       //!< Code describing what happened.
    QString         last_errstr;        //!< String describing what happened.
};

#endif // GIGE_SOCKET_H
