/*!
 * @file histo_dock.h
 * @brief This is the header file for the histogram dock.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef HISTO_DOCK_H
#define HISTO_DOCK_H

//--------------------------------------------------------------------
// Include Files
//--------------------------------------------------------------------
#include <QDockWidget>
#include <QVector>
#include <stdint.h>

namespace Ui
{
class HistoDock;
}

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------
class QByteArray;
class QMdiSubWindow;
class QTimer;

class CameraMDI;
class fiHistogram;
class fiHistoProc;
class PlaybackMDI;

//--------------------------------------------------------------------
// Class Declaration
//--------------------------------------------------------------------
class HistoDock : public QDockWidget
{
    Q_OBJECT

public:
    explicit HistoDock(QWidget *parent = nullptr, bool useTimer = true);
    ~HistoDock();

    void    disconnect_camera();
    CameraMDI   *get_camera()              { return active_camera; }

    fiHistogram *get_histogram();
    void    set_raw_mode(bool use_raw);
    void    single_shot();
    void    enable_timer(bool do_timer);
    void    override_roi(QRect roi);
    void    use_local_histogram(bool use_local);

protected:
    virtual void    changeEvent(QEvent *event);
    virtual void    closeEvent(QCloseEvent *event);
    virtual void    contextMenuEvent(QContextMenuEvent *event_ptr);

public slots:
    void    copy_data();
    void    copy_image();
    void    pause();
    void    resume();
    void    time_to_update();

    virtual void    setVisible(bool visible);

private slots:
    void    do_dock();
    void    finish_setup();
    void    new_active_camera(QMdiSubWindow *window);
    void    parent_closing();
    void    read_complete(uint32_t ip_addr, uint32_t reg_addr);
    void    stream_live();
    void    stream_paused();
    void    toggle_histogram();
    void    toggle_statistics();
    void    update_histo();
    void    zoom_in();
    void    zoom_out();
    void    zoom_reset();
    void    zoom_user();

private:
    void    histo_read_start();
    void    histo_read_update();
    void    translate_ui();
    void    update_remote();
    void    update_local();

private:
    Ui::HistoDock *ui;

    CameraMDI           *active_camera;     //!< Pointer to the active camera.
    PlaybackMDI         *active_mdi;        //!< Pointer to the MDI child if it's not a live camera.

    fiHistoProc         *histo_proc;        //!< Histogram processing object.
    QVector<uint32_t>   histo_data;         //!< The actual histogram data we download from the camera.
    uint32_t            histo_size;         //!< The number of bytes in our histogram data.
    bool                histo_local;        //!< Use the locally generated histogram (not the one from the camera).
    bool                roi_override;
    QRect               roi_rect;
    bool                single_in_progress; //!< Flag to indicate we're doing a single shot update.
    bool                update_paused;      //!< True if we've paused the update timer.
    QTimer              *update_timer;      //!< The timer we're using to update the histogram.
    bool                use_timer;          //!< True if we're using the timer to update the histogram.
};

#endif // HISTO_DOCK_H
