/*!
 * @file ip_ctrl.h
 * @brief This file contains the declaration of the IPCtrl
 *        widget, a widget to make the user display/input of
 *        an IP address easier/better.
 *
 * Copyright 2014 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef IP_CTRL_H
#define IP_CTRL_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <QFrame>
#include <QLineEdit>
#include <QIntValidator>
#include <QHBoxLayout>
#include <QHostAddress>
#include <QFont>
#include <QLabel>
#include <QKeyEvent>

#include <stdint.h>

class IPCtrl : public QFrame
{
    Q_OBJECT

public:
    IPCtrl( QWidget *parent = 0 );
    ~IPCtrl();

    virtual bool eventFilter( QObject *obj, QEvent *event );

    QHostAddress    get_addr( void );
    void            set_addr( const QHostAddress &user_addr );

public slots:
    void slotTextChanged( QLineEdit* pEdit );

signals:
    void signalTextChanged( QLineEdit* pEdit );

private:
    void MoveNextLineEdit( int i );
    void MovePrevLineEdit( int i );

private:
    enum
    {
        QTUTL_IP_SIZE   = 4,    //!< The number of octets which make up an IP address.
        MAX_DIGITS      = 3     //!< The number of characters in the LineEdit.
    };

    QLineEdit *m_pLineEdit[ QTUTL_IP_SIZE ];
};

#endif // IP_CTRL_H
