/*!
 * @file jc_local.h
 * @brief This is the header file for the jcLocal class.
 *
 * Because of issues with QObject, this must be in its own
 * separate header and source file.
 *
 * Copyright 2020 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef JC_LOCAL_H
#define JC_LOCAL_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <QObject>
#include <memory>

//--------------------------------------------------------------------
// Class Forward Declarations
//--------------------------------------------------------------------

class QProcess;

namespace FI_JOURNALCTL
{
//--------------------------------------------------------------------
// Class Declaration for jcLocal
//--------------------------------------------------------------------

class jcLocal : public QObject
{
    Q_OBJECT

public:
    explicit jcLocal(QObject *parent = nullptr);
    ~jcLocal();

    void close();
    const QString getErrorString();
    void run(const QString& cmd, const QStringList& args);
    QString runAndWait(const QString& cmd, const QStringList& args);

    bool isRunning();

signals:
    void dataAvailable(QString log_data);

private slots:
    void processHasData();

private:
    QString error_info;                                         //!< Text representing what might have gone wrong.
    std::unique_ptr<QProcess> my_process;

};

} // End of FI_JOURNALCTL

#endif // JC_LOCAL_H
