/*!
 * @file jc_remote.h
 * @brief This is the header file for the jcRemote class.
 *
 * Because of issues with QObject, this must be in its own
 * separate header and source file.
 *
 * Copyright 2020 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef JC_REMOTE_H
#define JC_REMOTE_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <QFuture>
#include <QMutex>
#include <QObject>
#include <QWaitCondition>

#include <libssh/libssh.h>
#include <libssh/callbacks.h>

#include "fi_journalctl.h"

namespace FI_JOURNALCTL
{

//--------------------------------------------------------------------
// Class Declaration for jcRemote
//--------------------------------------------------------------------

class jcRemote: public QObject
{
    Q_OBJECT

public:
    explicit jcRemote(QObject *parent = nullptr);
    ~jcRemote();

    void close();
    void run(const QString& requested_cmd, const QStringList& args);
    QString runAndWait(const QString& requested_cmd, const QStringList& args);

    const QString getErrorString()      { return error_info; }

    bool setSecurity(const FI_JOURNALCTL::SSH_SETTINGS *ssh_info);

    bool isRunning();

signals:
    void dataAvailable(QString log_data);

private slots:
    void processHasData();

private:
    static void sshHandler(QObject *parent);
    bool initSSHChannel();

private:
    QString error_info;                                         //!< Text representing what might have gone wrong.
    QFuture<void> ssh_thread;                                   //!< Our SSH processing thread "handle".
    volatile bool thread_stop;                                  //!< Flag to tell our processing thread to stop.
    volatile bool new_cmd_pending;                              //!< Flag to tell our processing thread that there's a new command pending.

    QWaitCondition  worker_wakeup;                              //!< Synchronization object to inform the worker thread that there's something to do.
    QMutex cmd_mutex;                                           //!< Mutex to guard access to the cmd.
    QString cmd;                                                //!< The command we want to send to the remote host.

    ssh_session ssh;                                            //!< The SSH session object.
    ssh_channel channel;                                        //!< The SSH channel object.
    QMutex ssh_mutex;                                           //!< Protect the SSH channel object.
};


} // End of FI_JOURNALCTL

#endif // JC_REMOTE_H
