/*!
 * @file jump_dialog.h
 * @brief This is the header file for the JumpDialog class.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef JUMP_DIALOG_H
#define JUMP_DIALOG_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <QDialog>
#include <stdint.h>

namespace Ui
{
class JumpDialog;
}

//-----------------------------------------------------------------------------
// Class Forward Declarations
//-----------------------------------------------------------------------------

class PlaybackMetaInfo;

//--------------------------------------------------------------------
// Class: JumpDialog
//--------------------------------------------------------------------
class JumpDialog : public QDialog
{
    Q_OBJECT

public:
    explicit JumpDialog(QWidget *parent = nullptr);
    ~JumpDialog();

    void    set_pfmeta(PlaybackMetaInfo *meta_ptr);
    void    set_rel_time(int32_t min_frame, int32_t max_frame, int32_t cur_frame, int32_t trig_frame, int32_t fps);
    void    use_rel_time(bool do_rel_time = true);
    uint32_t    get_frame();

public slots:
    int exec() override;

private slots:
    void    absolute_clicked();
    void    relative_clicked();
    void    frame_changed(int new_frame);
    void    seconds_changed(double new_value);
    void    minutes_changed(int new_value);
    void    hours_changed(int new_value);
    void    days_changed(int new_value);
    void    years_changed(int new_value);
    void    position_changed(int new_value);

private:
    void    parse_rel_time();
    void    parse_abs_time();
    int32_t time_to_frame();
    void    update_display();
    void    time_changed();
    double  trigger_time();

    void    block_controls(bool do_block);

private:
    Ui::JumpDialog *ui;                 //!< Our UI object.

    bool    use_relative_time;          //!< True to use relative time, false for absolute time.
    int32_t frame_rate;                 //!< The frame rate at which the recording was taken.
    int32_t cur_frame;                  //!< The current frame (relative to the trigger).
    int32_t trigger_frame;              //!< The trigger frame.
    PlaybackMetaInfo    *meta_info;     //!< Playback meta information.
};

#endif // JUMP_DIALOG_H
