/*!
 * @file playback_cap.h
 * @brief This is the header file for the PlaybackCap class.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef PLAYBACK_CAP_H
#define PLAYBACK_CAP_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include "fi_rawfile.h"
#include "fi_metamap.h"
#include "playback_mdi.h"

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

class fiPixmap;
struct pm_metadata_type;

//--------------------------------------------------------------------
// Class Definition
//--------------------------------------------------------------------
class PlaybackCap : public PlaybackMDI
{
    Q_OBJECT

public:
    explicit PlaybackCap(QWidget *parent = nullptr);
    virtual ~PlaybackCap();

    QString getFile() override             { return root_file; }
    const QByteArray& getRawImage() const override;
    bool loadFrame(uint32_t frame_num, fiPixmap *pixmap_ptr, bool force_load = false) override;
    bool setFile(const QString& filename) override;
    void setInactive() override;

protected:
    // Qt protected event methods.
    void contextMenuEvent(QContextMenuEvent *event_ptr) override;
    void focusInEvent(QFocusEvent *event) override;
    bool getRawMarkers(uint32_t starting_frame_num, uint32_t frame_count, bool do_swap) override;

protected slots:
    void doImageSave() override;
    void saveImagesCompleted(bool savedOK) override;

private:

    bool init_metadata();
    bool prepare_to_frameload(uint32_t absFrameNum, uint32_t& capFrameIndex);
    bool refresh_pm_metadata();
    bool save_pm_metadata(const QString& filename);
    bool save_raw_metadata(const QString& filename);
    bool set_vtrig_marker(int index, uint32_t& event_word, uint32_t *compare_ptr, uint32_t vtrig_word, uint32_t last_vtrig_word);

    static void SaveImages(QObject *parent);

private:

    uint32_t capIdActive;                           //!< The capId that is active for our capRawFile.
    uint32_t capEventsPFMDLastCapId;                //!< The capId of the last cap pushed into the capEventsPFMD byte array.
    QByteArray capEventsPFMD;                       //!< Collected pfmd from all cap files in fflr stack for event searching.
    QSharedPointer<fiRawFile> capRawFile;           //!< A raw cap file object.
    QSharedPointer<FI_METAMAP::FiMetaMap> metamap;  //!< Supports one or more CAP files to playback.
};

#endif // PLAYBACK_CAP_H
