/*!
 * @file playback_meta_info_fflr.h
 * @brief This is the header file for displaying meta file information about a CAP
 *        stack of files created with FasFireLR.
 *
 * Copyright 2022 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef PLAYBACK_META_INFO_FFLR_H
#define PLAYBACK_META_INFO_FFLR_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include "playback_meta_info.h"
#include "fi_metamap.h"

//--------------------------------------------------------------------
// Class Definition
//--------------------------------------------------------------------
class PlaybackMetaInfoFFLR : public PlaybackMetaInfo
{
    Q_OBJECT

public:
    explicit PlaybackMetaInfoFFLR(QWidget *parent = nullptr);
    virtual ~PlaybackMetaInfoFFLR();

    bool installMetaMap(QSharedPointer<FI_METAMAP::FiMetaMap> fflrMMPtrToSet);

    uint32_t    getStartFrame() override;
    uint32_t    getEndFrame() override;
    uint32_t    getTriggerFrame() override;
    uint32_t    getFrameCount() override;

    uint8_t     *getRawEventFlags(int pfmd_len = 0, bool do_swap = true) override;
    QByteArray  *getRawPFMD(uint32_t frame_num, bool do_swap = true) override;

    uint32_t    getPfmdTime(uint32_t frame_num, uint32_t& time_usec, int pfmd_len = 0) override;
    bool        getPfmdTimeStr(uint32_t frame_num, QString& time_str, int pfmd_len = 0) override;

    uint32_t    findFrame(uint32_t time_sec, uint32_t time_usec, int pfmd_len = 0) override;

    void        setMetadataFile(const QString& meta_filename) override;

private:
    QSharedPointer<FI_METAMAP::FiMetaMap> fflrMMPtr;   //!< The metamap representing the FasFireLR CAP stack.
};

#endif // PLAYBACK_META_INFO_FFLR_H
