/*!
 * @file select_drive.h
 * @brief This is the header file for the SelectDrive class.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef PLAYBACK_RAW_MDI_H
#define PLAYBACK_RAW_MDI_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include "playback_mdi.h"

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

class fiPixmap;
class fiRawDrive;
struct pm_metadata_type;

//--------------------------------------------------------------------
// Class Definition
//--------------------------------------------------------------------
class PlaybackRawMDI : public PlaybackMDI
{
    Q_OBJECT

public:
    explicit PlaybackRawMDI(QWidget *parent = nullptr);
    ~PlaybackRawMDI();

    QString getFile() override                      { return root_file; }
    const QByteArray& getRawImage() const override;
    bool loadFrame(uint32_t frame_num, fiPixmap *pixmap_ptr, bool force_load = false) override;
    bool setFile(const QString& filename) override;
    void setInactive() override;

protected:
    // Qt protected event methods.
    void contextMenuEvent(QContextMenuEvent *event_ptr) override;
    void focusInEvent(QFocusEvent *event) override;

protected slots:
    void doImageSave() override;
    virtual void saveImagesCompleted(bool savedOK) override;

private:
    bool initMetadata();
    bool savePmMetadata(const QString& filename);
    bool saveRawPerFrameMetadata(const QString& filename);

    static void SaveImages(QObject *parent);

private:

    QSharedPointer<fiRawDrive> rawDrive;     //!< A raw drive object.
};

#endif // PLAYBACK_RAW_MDI_H
