/*!
 * @file raw_to_xml.h
 * @brief This header file defines the RawToXML class. The class is used to convert
 *        raw per-frame metadata to an XML formatted file.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef RAWTOXML_H
#define RAWTOXML_H

#include <QObject>
#include <QThread>
#include <QXmlStreamWriter>
#include <qendian.h>
#include "gige_msg.h"

//--------------------------------------------------------------------
// Class Definition
//--------------------------------------------------------------------
class RawToXML : public QObject
{
    Q_OBJECT
public:
    explicit RawToXML(QObject *parent = nullptr);
    ~RawToXML();

    void        set_gains(uint32_t red, uint32_t green, uint32_t blue);
    void        set_params(const QString& pm_file_path, const QString& xml_file_path, const pm_metadata *session_meta_ptr, uint32_t start_frame, uint32_t end_frame);

signals:
    void        finished();
    void        error(QString err);

public slots:
    void        cancel_convert();
    void        start_convert();

private:
    void    sbs_to_tm(uint32_t sbs, struct tm *tm_ptr);
    void    save_capture_metadata(void);
    void    save_normalization_metadata(void);
    void    save_record_metadata(void);
    void    save_camera_metadata(void);
    void    save_image_metadata(void);
    void    save_one_frame_metadata(const uint32_t *frame_words, uint32_t frame_no);
    void    save_frame_metadata(void);

private:
    bool                series3_found;              //!< True if this is a series3 camera.
    bool                stop_processing;            //!< Flag to stop the conversion process.
    uint32_t            start_frame;                //!< The starting frame number.
    uint32_t            end_frame;                  //!< The ending frame number (inclusive).
    uint32_t            red_gain;                   //!< The display red gain.
    uint32_t            green_gain;                 //!< The display green gain.
    uint32_t            blue_gain;                  //!< The display blue gain.
    uint32_t            pfmd_word_len;              //!< Number of words in the per-frame metadata array.
    QString             raw_file_path;              //!< Fully qualified path to the raw per-frame metadata file.
    QString             xml_file_path;              //!< Fully qualified path to the XML file.
    pm_metadata         session_metadata;           //!< The capture metadata.

    QXmlStreamWriter    writer;                     //!< Our XML writing object.
};

#endif // RAWTOXML_H
