/*!
 * @file regcache_init.h
 * @brief This header file extracts the cache settings initialization values
 *        out of the source file to make the source file easier to read.
 *
 * Copyright 2014 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef REGCACHE_INIT_H
#define REGCACHE_INIT_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include "regcache.h"
#include "gige_msg.h"

namespace FI_COMM
{
//--------------------------------------------------------------------
// Constant, Macro and Type Definitions
//--------------------------------------------------------------------

//! The default flag value for our cache entries.
const int   DEFAULT_FLAG                = 0;

//! The default lifetime of our cache entries.
const int   DEFAULT_LIFE_SEC            = 2;
const int   DEFAULT_LIFE_MSEC           = 0;

//! An array of values to initialize the cache settings for specific registers.
const REG_CACHE::CACHE_SETTING  INIT_VALUES[] =
{
    {
        GIGE_REG_BIT_MODE, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_BRIGHTNESS, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_CONTRAST, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_EXT_TRIG_ENABLE, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_FPN,       // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_FRAME_RATE,    // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_HDMI,      // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_HEIGHT,    // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_IMAGE_DESTINATION, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_LTR_MODE, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_LTR_SECTOR_COUNT,     // .addr
        DEFAULT_FLAG,       // .flag
        0,                  // .expire_sec
        500,                // .expire_msec
    },
    {
        GIGE_REG_MAX_FRAME_RATE,    // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_MAX_SHUTTER_SPEED, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_MIN_SHUTTER_SPEED, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_OFFSET_X,  // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_OFFSET_Y,  // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_PART_STATE, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_SAVE_END_NUM, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_SAVE_START_NUM, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_SHUTTER_SPEED, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_STREAM_CONTROL, // .addr
        DEFAULT_FLAG,       // .flag
        0,                  // .expire_sec
        200,                // .expire_msec
    },
    {
        GIGE_REG_TIMEOFDAY, // .addr
        DEFAULT_FLAG,       // .flag
        0,                  // .expire_sec
        900,                // .expire_msec
    },
    {
        GIGE_REG_TRIGGER_REQ_POS, // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },
    {
        GIGE_REG_WIDTH,     // .addr
        DEFAULT_FLAG,       // .flag
        DEFAULT_LIFE_SEC,   // .expire_sec
        DEFAULT_LIFE_MSEC,  // .expire_msec
    },

    //----------------------------------------------
    // Don't cache
    //----------------------------------------------
    {
        GIGE_REG_AUTOSAVE,          // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,                  // .expire_sec
        0,                  // .expire_msec
    },
    {
        GIGE_REG_CONFIGURATION,     // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_CSI_RVW_FRAME_NUM, // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_FILEPATH,          // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_HISTO_RGB,         // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_HISTOGRAM_RAW,     // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_PB_CONTROL,   // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_PB_STATUS,   // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_PB_CUT_IN_FRAME,   // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_PB_CUT_OUT_FRAME,  // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_PB_LAST_FRAME,     // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_SAVE_STATE,        // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_WIFI_STATUS,       // .addr
        REG_CACHE::ENTRY_NO_CACHE,  // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },

    //----------------------------------------------
    // One time reads
    //----------------------------------------------
    {
        GIGE_REG_DEF_GATEWAY,           // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_DEVICE_VER,            // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_FIRMWARE_VER,          // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_FRAME_OVERHEAD,        // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_GIGE_VER,              // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_LTR_MODE,
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_MAC_HIGH,              // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_MAC_LOW,               // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_MAN_INFO,              // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_MAN_NAME,              // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_MEM_SIZE,              // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_MEM_SIZE_RESERVED,     // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_MIN_HEIGHT,            // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_MIN_SHUTTER_SPEED,     // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_MODEL_NAME,            // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_SENSOR_HEIGHT,         // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_SENSOR_TYPE,           // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_SENSOR_WIDTH,          // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_SERIAL_NUM,            // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_SSD_BANDWIDTH,
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_SUBNET_MASK,           // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_XML_URL_1,             // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_XML_URL_2,             // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
    {
        GIGE_REG_ICM_MODULE_VER,        // .addr
        REG_CACHE::ENTRY_NEVER_EXPIRES, // .flag
        0,          // .expire_sec
        0,          // .expire_msec
    },
};

//! The number of entries in the INIT_VALUES array.
const int   INIT_LIST_LEN = sizeof(FI_COMM::INIT_VALUES) / sizeof(FI_COMM::INIT_VALUES[0]);

}   // End of namespace FI_COMM.

#endif // REGCACHE_INIT_H
