/*!
 * @file save_snapshot.h
 * @brief This is the header file for the SaveSnapshot class.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef SAVE_SNAPSHOT_H
#define SAVE_SNAPSHOT_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <QDialog>
#include <QPixmap>
#include <stdint.h>

namespace Ui
{
class SaveSnapshot;
}

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------
class QGraphicsScene;

//--------------------------------------------------------------------
// Class Definition
//--------------------------------------------------------------------
class SaveSnapshot : public QDialog
{
    Q_OBJECT

public:
    explicit SaveSnapshot(QWidget *parent = 0);
    ~SaveSnapshot();

    void    set_image(const QPixmap& snap_image);

protected:
    virtual void    resizeEvent(QResizeEvent *event);

private slots:
    void    do_chk_tag_label(int state);
    void    do_save(void);
    void    do_toggle_pc(bool checked);
    void    query_save_status(void);
    void    force_a_resize(void);
    void    read_complete(uint32_t ip_addr, uint32_t reg_addr);
    void    write_complete(uint32_t ip_addr, uint32_t reg_addr);

private:
    void    get_filename(QString& file_name);
    void    init_controls(void);
    void    process_save_status(void);
    void    restore_settings(void);
    void    save_to_camera(void);
    void    save_to_pc(void);

private:
    Ui::SaveSnapshot *ui;

    bool                err_received;                   //!< Flag to remember if we get an error.
    QGraphicsScene      *scene_ptr;                     //!< Pointer to our Qt "scene" object.
    QPixmap             snap_pixmap;                    //!< Our pixmap for the snapshot.
};

#endif // SAVE_SNAPSHOT_H
