#ifndef SELECT_FOLDER_H
#define SELECT_FOLDER_H

#include <QDialog>
#include <QFile>
#include <QJsonArray>
#include <QJsonObject>
#include <QModelIndex>
#include <QString>

#include <stdint.h>

#include "camera_explore.h"

namespace Ui
{
class SelectFolder;
}

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

class QTreeWidgetItem;


class SelectFolder : public QDialog
{
    Q_OBJECT

public:
    explicit SelectFolder(QWidget *parent = nullptr);
    ~SelectFolder();

    QString folderSelected();
    void reset();
    void setJsonInfo(const QJsonObject& json_info, const QJsonArray& json_array);

public slots:
    int exec() override;

protected:
    void timerEvent(QTimerEvent *event) override;

private slots:
    void doTreeExpansion(QModelIndex model_index);
    void doTreeItemChanged(QTreeWidgetItem *item, QTreeWidgetItem *prev);
    void doTreeItemDoubleClicked(QTreeWidgetItem *item, int column);
    void doTreeSelectionChanged();
    void handleFAStatus(uint32_t fa_status);
    void handleListingDownload();
    void listingStart();
    void readComplete(uint32_t ip_addr, uint32_t reg_addr);
    void writeComplete(uint32_t ip_addr, uint32_t reg_addr);

private:
    bool buildMediaPath();
    void displayMetadata(const CAM_EXPLORE::FILE_INFO *file_info);
    const CAM_EXPLORE::FILE_INFO *getFileInfo(const QTreeWidgetItem *item, int& row_out);
    void listingFinish();
    void parseListing();
    void writeFilepathDone(uint32_t write_status);

private:
    Ui::SelectFolder *ui;

    QList<CAM_EXPLORE::FILE_INFO>  cam_folders;         //!< Collection to hold the folder data parsed from the XML file
    int         file_timer_id;                          //!< Timer used when doing a file operation to update the progress dialog.
    QFile       listing_file;                           //!< File name for the XML directory listing from the camera.
    uint32_t    listing_len;                            //!< The number of bytes in the listing from the camera.
    QJsonArray  media_array;                            //!< Array of JSON objects describing the media on the camera.
    QJsonObject media_info;                             //!< May be NULL, the JSON info for the media selected.
    QString     media_path;                             //!< Camera path for the folder we want a listing from.
};

#endif // SELECT_FOLDER_H
