#ifndef SELECT_ITEM_H
#define SELECT_ITEM_H

#include <QDialog>

namespace Ui
{
class SelectItemDlg;
}

class SelectItemDlg : public QDialog
{
    Q_OBJECT

public:
    explicit SelectItemDlg(QWidget *parent = 0);
    ~SelectItemDlg();

    enum
    {
        ABS_FRAME = 0,
        ABS_TIME,
        BIT_SEL,
        CUSTOM_TEXT,
        DURATION,
        EVENT,
        EXPOSURE,
        FRAME_COUNT,
        FRAMERATE,
        GAIN,
        MAC,
        MANUFACTURER,
        MODEL,
        NAME,
        REL_FRAME,
        REL_TIME,
        REL_FTIME,
        ROI,
        SENSOR_OPT,
        SMPTE_TIME,
        SYNC_SOURCE,
        TIME_OFFSET,
        TIME_SOURCE,
        TRIGGER_POS,
        VERSION,
        VT_FLAGS,
        VT_CHANGE,
        OPTION_COUNT
    };

    static const QString get_label(int item_id);

    const QString   custom_ftime_frame();
    const QString   custom_text();
    QList<int>      get_visible_list();
    bool    item_is_selected(int item_id);
    void    select_item(int item_id);
    void    set_custom_ftime_frame(const QString& user_text, int ftime_frame_min, int ftime_frame_max);
    void    set_custom_text(const QString& user_text);

public slots:
    virtual void    accept();
    virtual int     exec();

private slots:
    void    do_add();
    void    do_ftime_range_check();
    void    do_move_up();
    void    do_move_down();
    void    do_remove();
    void    do_reset();
    void    do_visible_sel_changed();

private:
    void    set_up_custom_text();
    void    set_up_custom_ftime();

    Ui::SelectItemDlg *ui;
    QStringList     avail_items;
    QStringList     used_items;
    QString         custom_text_data;
    QString         custom_ftime_data;
    int             custom_ftime_min_rel_frame;
    int             custom_ftime_max_rel_frame;

    // The labels used for the overlays.
    static const QString   ABS_FRAME_LABEL;
    static const QString   ABS_TIME_LABEL;
    static const QString   BIT_SEL_LABEL;
    static const QString   CUSTOM_TEXT_LABEL;
    static const QString   DURATION_LABEL;
    static const QString   EVENT_LABEL;
    static const QString   EXPOSURE_LABEL;
    static const QString   FRAME_COUNT_LABEL;
    static const QString   FRAMERATE_LABEL;
    static const QString   GAIN_LABEL;
    static const QString   MAC_LABEL;
    static const QString   MANUFACTURER_LABEL;
    static const QString   MODEL_LABEL;
    static const QString   NAME_LABEL;
    static const QString   REL_FRAME_LABEL;
    static const QString   REL_TIME_LABEL;
    static const QString   REL_FTIME_LABEL;
    static const QString   REL_FTIME_PROMPT_LABEL;
    static const QString   ROI_LABEL;
    static const QString   SENSOR_OPT_LABEL;
    static const QString   SMPTE_TIME_LABEL;
    static const QString   SYNC_SOURCE_LABEL;
    static const QString   TIME_OFFSET_LABEL;
    static const QString   TIME_SOURCE_LABEL;
    static const QString   TRIGGER_POS_LABEL;
    static const QString   VERSION_LABEL;
    static const QString   VT_FLAGS_LABEL;
    static const QString   VT_CHANGE_LABEL;

    void    adjust_ui();
};

#endif // SELECT_ITEM_H
