/*!
 * @file user_preferences.h
 * @brief This is the header file for the UserPreferences dialog.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef USER_PREFERENCES_H
#define USER_PREFERENCES_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <QDialog>

#include "logger.h"

namespace Ui
{
class UserPreferences;
}

namespace USER_PREFERENCES
{
//--------------------------------------------------------------------
// Constant, Macro and Type Definitions
//--------------------------------------------------------------------

}   // End of namespace UPDATE_STATUS.

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

class QCheckBox;
class QListWidgetItem;

//--------------------------------------------------------------------
// Class declaration: UserPreferences
//--------------------------------------------------------------------
class UserPreferences : public QDialog
{
    Q_OBJECT

public:
    explicit UserPreferences(QWidget *parent = nullptr);
    ~UserPreferences();

    static const QString SERIESNC_CAM_USER_DEFAULT_NAME;
    static const QString SERIESNC_CAM_USER_DEFAULT_WORKGROUP;
    static const QString SERIESNC_CAM_USER_PREF_KEY;
    static const QString SERIESNC_CAM_PASS_PREF_KEY;
    static const QString SERIESNC_CAM_WORKGROUP_KEY;
    static const QString SERIESNC_PREFERENCES_SECTION;

    int     GetBackoffBuffers();
    void    GetCredentials(QString& username, QString& password, QString& workgroup);
    QsLogging::Level GetLoggingLevel();
    int     GetNetworkBufferCount();
    int     GetPacketDelay();
    QString GetPuttyPath();
    int     GetUpdateFreq();

    bool    AutoConnectEnabled();
    bool    AutoUpdateEnabled();
    bool    FactoryMenuEnabled();
    bool    MulticamEnabled();
    bool    SaveStatsEnabled();

    void    SetAutoConnect(bool show, bool enable);
    void    SetBackoffBuffers(int backoff_bufs);
    void    SetCredentials(const QString& username, const QString& password, const QString& workgroup);
    void    SetFactoryEnable(bool do_enable);
    void    SetLoggingLevel(QsLogging::Level log_level);
    void    SetMulticamEnable(bool do_enable);
    void    SetNetworkBuffers(int net_bufs);
    void    SetPacketDelay(int pkt_delay);
    void    SetPuttyPath(const QString& the_path);
    void    SetSaveStatsEnable(bool do_enable);


public slots:
    virtual void accept();

private slots:
    void    browsePutty();
    void    checkTimeChanged(int index);
    void    changePage(QListWidgetItem *current, QListWidgetItem *previous);
    void    doCheck();
    void    doBrowseDownloadPath();
    void    doDownloadPackage();
    void    doSelectPackage();
    void    downloadNext(int which_update);
    void    showPassword();
    void    updateBackoff(int num_net_buffers);

    void    updateFinished(int updates_avail);
    void    updateError(int err_value);

private:
    Ui::UserPreferences *ui;
    QCheckBox   *factoryMenuEnable;
    QList<int>  download_list;
    QString serverUrl;

    void    displayUpdates();
    void    initUpdatePage();
    void    initNetworkInterface();

};

#endif // USER_PREFERENCES_H
