/*!
 * @file whitebal_dialog.h
 * @brief This is the header file for the custom white balance selection
 *        dialog.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef WHITEBAL_DIALOG_H
#define WHITEBAL_DIALOG_H

//--------------------------------------------------------------------
// Include Files
//--------------------------------------------------------------------
#include <QDialog>
#include <QVector>
#include <stdint.h>

namespace Ui
{
class WhiteBalDlg;
}

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------
class QByteArray;
class QGraphicsRectItem;
class QGraphicsScene;

//--------------------------------------------------------------------
// Class Declaration
//--------------------------------------------------------------------
class WhiteBalDlg : public QDialog
{
    Q_OBJECT

public:
    explicit WhiteBalDlg(QWidget *parent = nullptr);
    ~WhiteBalDlg();

    int     get_cct()       { return cct; }
    QRect   get_roi();

    void    set_ip_addr(uint32_t ip_addr)         { cam_ip_addr = ip_addr; }
    void    set_scene(QGraphicsScene *scene_ptr);

public slots:
    virtual int     exec();

private slots:
    void    finish_init();
    void    read_complete(uint32_t ip_addr, uint32_t reg_addr);
    void    show_histo();
    void    time_to_update();
    void    update_histo();
    void    update_image(int pos, int index);

protected:
    virtual void    resizeEvent(QResizeEvent *event);

private:
    void    histo_read_start();
    void    histo_read_update();

private:
    Ui::WhiteBalDlg *ui;

    uint32_t            cam_ip_addr;        //!< IP address of the camera we're talking to.
    QVector<uint32_t>   histo_data;         //!< The actual histogram data we download from the camera.
    uint32_t            histo_size;         //!< The number of bytes in our histogram data.
    QGraphicsRectItem   *reticle;           //!< The region we'll be sampling for the custom white balance gains.
    QTimer              *update_timer;      //!< The timer we're using to update the histogram.
    int                 cct;                //!< Correlated color temperature.
};

#endif // WHITEBAL_DIALOG_H
