/*!
 * @file wifi_scan.h
 * @brief Header for the WIFI scanning dialog.
 *
 * Copyright 2014 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef WIFI_SCAN_H
#define WIFI_SCAN_H

#include <QDialog>
#include <QModelIndex>
#include <stdint.h>

#include "gige_msg.h"

namespace Ui
{
class WifiScan;
}

class WifiScan : public QDialog
{
    Q_OBJECT

public:
    explicit WifiScan(QWidget *parent = nullptr);
    ~WifiScan();

    const wifi_scan_results *get_ap_info(void) const;

    void set_ssid(QString ssid_str)        { cur_ssid = ssid_str; }

public slots:
    virtual int exec();

private slots:
    void ap_selected(QModelIndex model_index);
    void on_cancel(void);
    void on_ok(void);
    void on_scan(void);
    void read_complete(uint32_t ip_addr, uint32_t reg_addr);
    void scan_timeout(void);
    void write_complete(uint32_t ip_addr, uint32_t reg_addr);

private:
    Ui::WifiScan *ui;

    QString                     cur_ssid;           //!< SSID currently being used, if any.
    QList<wifi_scan_results>    scan_list;          //!< List of scanned AP nodes.
};

#endif // WIFI_SCAN_H
